@@ -1,5 +1,5 @@
 /*
-    $Id: vcdimager.c,v 1.37 2001/08/29 14:52:06 hvr Exp $
+    $Id: vcdimager.c,v 1.40 2003/01/06 17:19:59 hvr Exp $
 
     Copyright (C) 2001 Herbert Valerio Riedel <hvr@gnu.org>
 
@@ -38,7 +38,7 @@
 #include <libvcd/vcd_stream_stdio.h>
 #include <libvcd/vcd_types.h>
 
-static const char _rcsid[] = "$Id: vcdimager.c,v 1.37 2001/08/29 14:52:06 hvr Exp $";
+static const char _rcsid[] = "$Id: vcdimager.c,v 1.40 2003/01/06 17:19:59 hvr Exp $";
 
 /* defaults */
 #define DEFAULT_CUE_FILE       "videocd.cue"
@@ -57,8 +57,7 @@ struct add_files_t {
   int raw_flag;
 };
 
-static struct
-{
+static struct {
   const char *type;
   const char *image_fname;
   const char *cue_fname;
@@ -79,10 +78,10 @@ static struct
 
   int verbose_flag;
   int quiet_flag;
+  int check_flag;
 
   vcd_log_handler_t default_vcd_log_handler;
-}
-gl;                             /* global */
+} gl = { 0, };                             /* global */
 
 
 static void
@@ -248,6 +247,9 @@ main (int argc, const char *argv[])
         {"progress", 'p', POPT_ARG_NONE | POPT_ARGFLAG_DOC_HIDDEN,
          NULL, 0, "show progress"},
 
+        {"check", '\0', POPT_ARG_NONE | POPT_ARGFLAG_DOC_HIDDEN, 
+         &gl.check_flag, 0, "enabled check mode"},
+
         {"verbose", 'v', POPT_ARG_NONE, &gl.verbose_flag, 0, "be verbose"},
 
         {"quiet", 'q', POPT_ARG_NONE, &gl.quiet_flag, 0, 
@@ -262,6 +264,7 @@ main (int argc, const char *argv[])
       };
     
     poptContext optCon = poptGetContext ("vcdimager", argc, argv, optionsTable, 0);
+    poptSetOtherOptionHelp (optCon, "[OPTION...] <mpeg-tracks...>");
 
     if (poptReadDefaultConfig (optCon, 0)) 
       fprintf (stderr, "warning, reading popt configuration failed\n"); 
@@ -365,6 +368,9 @@ main (int argc, const char *argv[])
 
   gl_vcd_obj = vcd_obj_new (type_id);
 
+  if (gl.check_flag)
+    vcd_obj_set_param_str (gl_vcd_obj, VCD_PARM_PREPARER_ID, "GNU VCDIMAGER CHECK MODE");
+
   vcd_obj_set_param_str (gl_vcd_obj, VCD_PARM_VOLUME_ID, gl.volume_label);
   vcd_obj_set_param_str (gl_vcd_obj, VCD_PARM_APPLICATION_ID, 
                          gl.application_id);
@@ -455,7 +461,7 @@ main (int argc, const char *argv[])
     vcd_obj_end_output (gl_vcd_obj);
 
     {
-      unsigned _bytes = sectors * (gl.sector_2336_flag ? M2RAW_SIZE : CDDA_SIZE);
+      unsigned _bytes = sectors * (gl.sector_2336_flag ? M2RAW_SECTOR_SIZE : CDDA_SECTOR_SIZE);
       char *_msfstr = _vcd_lba_to_msf_str (sectors);
 
       fprintf (stdout, 
