@@ -1,5 +1,5 @@
 /*
-    $Id: vcd_types.h,v 1.13 2001/08/25 09:38:17 hvr Exp $
+    $Id: vcd_types.h,v 1.18 2003/02/03 14:40:41 rocky Exp $
 
     Copyright (C) 2000 Herbert Valerio Riedel <hvr@gnu.org>
 
@@ -23,6 +23,10 @@
 
 /* provide some C99 definitions */
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 #if defined(HAVE_STDINT_H)
 # include <stdint.h>
 #elif defined(HAVE_INTTYPES_H)
@@ -128,17 +132,40 @@ typedef enum
 #define GNUC_PACKED
 #endif  /* !__GNUC__ */
 
+/* user directed static branch prediction
+ */
+#if __GNUC__ == 2 && __GNUC_MINOR__ < 96
+# define GNUC_LIKELY(x)   (x) 
+# define GNUC_UNLIKELY(x) (x)
+#else /* supported with gcc 2.96+ */
+# define GNUC_LIKELY(x)   __builtin_expect((x),true)
+# define GNUC_UNLIKELY(x) __builtin_expect((x),false)
+#endif
+
 #ifndef NULL
-#define NULL ((void*) 0)
+# define NULL ((void*) 0)
 #endif
 
 /* In many structures on the disk a sector address is stored as a
    BCD-encoded mmssff in three bytes. */
 typedef struct {
-  uint8_t m  GNUC_PACKED;
-  uint8_t s  GNUC_PACKED;
-  uint8_t f  GNUC_PACKED;
-} msf_t;
+  uint8_t m, s, f;
+} GNUC_PACKED msf_t;
+
+#define msf_t_SIZEOF 3
+
+/* The type of a Logical Block Address. */
+typedef uint32_t lba_t;
+ 
+/* The type of an Logical Sector Number. */
+typedef uint32_t lsn_t;
+
+/* The type of an playback control list ID (LID). */
+typedef uint16_t lid_t;
+
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
 
 #endif /* __VCD_TYPES_H__ */
 
